Tutorials
=========

Welcome!  You can find here a collection of tutorials that introduce the basic
functionalites of Swyft.  If anything is unclear, don't hesistate to ask
questions `here <https://github.com/undark-lab/swyft/discussions>`_.


.. toctree::
   :caption: Notebooks:
   :maxdepth: 1
   :glob:

   notebooks/Swyft*
   notebooks/0A*
   notebooks/0B*
   notebooks/0C*
   notebooks/0D*
   notebooks/0E*
   notebooks/0F*
   notebooks/0G*
   notebooks/0H*
   notebooks/01*
